@@ -54,83 +54,84 @@ class CortxJupyter(ContentsManager):
     def _multipart_uploads_default(self):
         return MultiPartUploadHelper(60 * 60 * 1)
 
-    def is_hidden(self, path):
+    def is_hidden(self, file_path):
         return False
 
-    def dir_exists(self, path):
+    def dir_exists(self, file_path):
 
         @gen.coroutine
         def dir_exists_async():
-            return (yield _check_directory_exists(self._config(), path))
+            return (yield _check_directory_exists(self._config(), file_path))
 
         return _run_sync(dir_exists_async)
 
-    def file_exists(self, path):
+    def file_exists(self, file_path):
 
         @gen.coroutine
         def file_exists_async():
-            return (yield _check_file_exists(self._config(), path))
+            return (yield _check_file_exists(self._config(), file_path))
 
         return _run_sync(file_exists_async)
 
-    def get(self, path, content=True, type=None, format=None):
+    def get(self, file_path, file_content=True, file_type=None, file_format=None):
 
         @gen.coroutine
         def get_async():
-            return (yield _get_model(self._config(), path, content, type, format))
+            return (yield _get_model(self._config(), file_path, file_content, file_type, file_format))
 
         return _run_sync(get_async)
 
     @gen.coroutine
-    def save(self, model, path):
+    def save(self, model, file_path):
         with (yield self.write_lock.acquire()):
-            return (yield _save_model(self._config(), model, path))
+            return (yield _save_model(self._config(), model, file_path))
 
     @gen.coroutine
-    def delete(self, path):
+    def delete(self, file_path):
         with (yield self.write_lock.acquire()):
-            yield _delete_notebook(self._config(), path)
+            yield _delete_notebook(self._config(), file_path)
 
     @gen.coroutine
-    def update(self, model, path):
+    def update(self, model, file_path):
         with (yield self.write_lock.acquire()):
-            return (yield _rename_notebook(self._config(), path, model['path']))
+            return (yield _rename_notebook(self._config(), file_path, model['path']))
 
     @gen.coroutine
-    def new_untitled(self, path='', type='', ext=''):
+    def new_untitled(self, file_path='', file_type='', extension=''):
         with (yield self.write_lock.acquire()):
-            return (yield _new_untitled_notebook(self._config(), path, type, ext))
+            return (yield _new_untitled_notebook(self._config(), file_path, file_type, extension))
 
     @gen.coroutine
-    def new(self, model, path):
+    def new(self, model, file_path):
         with (yield self.write_lock.acquire()):
-            return (yield _get_new_notebook(self._config(), model, path))
+            return (yield _get_new_notebook(self._config(), model, file_path))
 
     @gen.coroutine
-    def copy(self, from_path, to_path):
+    def copy(self, src_path, dest_path):
         with (yield self.write_lock.acquire()):
-            return (yield _copy_notebook(self._config(), from_path, to_path))
+            return (yield _copy_notebook(self._config(), src_path, dest_path))
 
     @gen.coroutine
-    def create_checkpoint(self, path):
+    def create_checkpoint(self, file_path):
         with (yield self.write_lock.acquire()):
-            return (yield _create_new_checkpoint(self._config(), path))
+            return (yield _create_new_checkpoint(self._config(), file_path))
 
     @gen.coroutine
-    def restore_checkpoint(self, checkpoint_id, path):
+    def restore_checkpoint(self, id, file_path):
         with (yield self.write_lock.acquire()):
-            return (yield _restore_notebook_checkpoint(self._config(), checkpoint_id, path))
+            return (yield _restore_notebook_checkpoint(self._config(), id, file_path))
 
     @gen.coroutine
-    def list_checkpoints(self, path):
-        return (yield _list_all_checkpoints(self._config(), path))
+    def list_checkpoints(self, file_path):
+        return (yield _list_all_checkpoints(self._config(), file_path))
 
     @gen.coroutine
-    def delete_checkpoint(self, checkpoint_id, path):
+    def delete_checkpoint(self, id, file_path):
         with (yield self.write_lock.acquire()):
-            return (yield _delete__notebook_checkpoint(self._config(), checkpoint_id, path))
+            return (yield _delete__notebook_checkpoint(self._config(),id, file_path))
 
     def _config(self):
+
         return Config(
             region=self.region_name,
             bucket_name=self.bucket_name,
